#
# spec file for package python-nose2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-nose2
Version:        0.9.1
Release:        3.3.4
Summary:        Second generation of the "nose" Python testing framework
License:        BSD-2-Clause AND Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/nose-devs/nose2
Source:         https://files.pythonhosted.org/packages/source/n/nose2/nose2-%{version}.tar.gz
Patch0:         remove_unittest2.patch
Patch1:         fix-mock-dep.patch
Patch2:         ignore-warnings-doctests.patch
BuildRequires:  %{python_module coverage >= 4.4.1}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.1}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-coverage >= 4.4.1
Requires:       python-six >= 1.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
nose2 is a new version of the nose unit testing framework,
supporting Python 2.6+ and 3.x, but not 2.4.
nose2 does not need a custom importer anymore and instead imports
modules with __import__. nose2 does not support all of the
test project layouts that nose did, and also does not
support package-level fixtures. Almost all configuration for nose2
is to be done through config files, not command-line options.

%prep
%setup -q -n nose2-%{version}
%autopatch -p1
rm -rf *.egg-info/

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/nose2

%check
export LC_CTYPE=C.UTF8
%python_exec setup.py test

%post
%python_install_alternative nose2

%postun
%python_uninstall_alternative nose2

%files %{python_files}
%license license.txt
%doc AUTHORS README.rst
%python_alternative %{_bindir}/nose2
%{python_sitelib}/*

%changelog
* Fri Dec 13 2019 adrian.glaubitz@suse.com
- Include in SLE-15 (bsc#1159018, jsc#PM-1507)
* Mon Nov 11 2019 steven.kowalik@suse.com
- Add ignore-warnings-doctests.patch to supress warnings when running
  doctests.
* Mon Sep 30 2019 tchvatal@suse.com
- Add dep on coverage as it is hard requirement based on requires
* Tue May 14 2019 tchvatal@suse.com
- Add patch to fix build with new mock versions:
  * fix-mock-dep.patch
* Mon Apr  8 2019 mimi.vx@gmail.com
- update to 0.9.1
- refresh remove_unittest2.patch
  * the prof plugin now uses cProfile instead of hotshot for profiling
  * skipped tests now include the user's reason in junit XML's message field
  * the prettyassert plugin mishandled multi-line function definitions
  * Using a plugin's CLI flag when the plugin is already enabled via config
  no longer errors
  * nose2.plugins.prettyassert, enabled with --pretty-assert
  * Cleanup code for EOLed python versions
  * Dropped support for distutils.
  * Result reporter respects failure status set by other plugins
  * JUnit XML plugin now includes the skip reason in its output
* Thu Aug 16 2018 jengelh@inai.de
- Avoid name repetition in summary (rpmlint).
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittest2
  Add remove_unittest2.patch to faciliate that
- Upgrade to 0.8.0:
    List of changes is too long to show here, see
    https://github.com/nose-devs/nose2/blob/master/docs/changelog.rst
    changes between 0.6.5 and 0.8.0
* Wed Jun 28 2017 jengelh@inai.de
- Update package description
* Mon Apr 24 2017 alarrosa@suse.com
- Use singlespec macros
* Mon Feb  6 2017 alarrosa@suse.com
- Initial release
